@@ -29,32 +29,17 @@ class RequestQueryParserMixin(object):
     This means `request.query_params` might not be available
     when this mixin is used.
     """
-    @staticmethod
-    def get_restql_query_param_name():
-        DEFAULT_QUERY_PARAM_NAME = 'query'
-        query_param_name = getattr(
-            restql_settings,
-            "QUERY_PARAM_NAME",
-            DEFAULT_QUERY_PARAM_NAME
-        )
-        return query_param_name
-
     @classmethod
     def has_restql_query_param(cls, request):
-        query_param_name = cls.get_restql_query_param_name()
+        query_param_name = restql_settings.QUERY_PARAM_NAME
         return query_param_name in request.GET
 
-    @classmethod
-    def get_raw_restql_query(cls, request):
-        query_param_name = cls.get_restql_query_param_name()
-        return request.GET[query_param_name]
-
     @classmethod
     def get_parsed_restql_query_from_req(cls, request):
         if hasattr(request, 'parsed_restql_query'):
             # Use cached parsed restql query
             return request.parsed_restql_query
-        raw_query = cls.get_raw_restql_query(request)
+        raw_query = request.GET[restql_settings.QUERY_PARAM_NAME]
         parser = Parser(raw_query)
         parsed_restql_query = parser.get_parsed()
 
@@ -66,7 +51,6 @@ class RequestQueryParserMixin(object):
 
 class QueryArgumentsMixin(RequestQueryParserMixin):
     """Mixin for converting query arguments into query parameters"""
-
     def get_parsed_restql_query(self, request):
         if self.has_restql_query_param(request):
             try:
@@ -79,7 +63,8 @@ class QueryArgumentsMixin(RequestQueryParserMixin):
         query = {
             "include": ["*"],
             "exclude": [],
-            "arguments": {}
+            "arguments": {},
+            "aliases": {},
         }
         return query
 
@@ -105,13 +90,11 @@ class QueryArgumentsMixin(RequestQueryParserMixin):
                     query_params.update(nested_query_params)
         return query_params
 
-    def get_query_params(self, request):
+    def inject_query_params_in_req(self, request):
         parsed = self.get_parsed_restql_query(request)
-        query_params = self.build_query_params(parsed)
-        return query_params
 
-    def dispatch(self, request, *args, **kwargs):
-        query_params = self.get_query_params(request)
+        # Generate query params from query arguments
+        query_params = self.build_query_params(parsed)
 
         # We are using `request.GET` instead of `request.query_params`
         # because at this point DRF request is not yet created so
@@ -121,6 +104,9 @@ class QueryArgumentsMixin(RequestQueryParserMixin):
 
         # Make QueryDict immutable after updating
         request.GET = QueryDict(params.urlencode(), mutable=False)
+
+    def dispatch(self, request, *args, **kwargs):
+        self.inject_query_params_in_req(request)
         return super().dispatch(request, *args, **kwargs)
 
 
@@ -129,12 +115,12 @@ class DynamicFieldsMixin(RequestQueryParserMixin):
         # Don't pass 'query', 'fields', 'exclude', 'return_pk'
         # and 'disable_dynamic_fields'  kwargs to the superclass
         self.parsed_restql_query = kwargs.pop('query', None)
-        self.allowed_fields = kwargs.pop('fields', None)
+        self.included_fields = kwargs.pop('fields', None)
         self.excluded_fields = kwargs.pop('exclude', None)
         self.return_pk = kwargs.pop('return_pk', False)
         self.disable_dynamic_fields = kwargs.pop('disable_dynamic_fields', False)
 
-        is_field_kwarg_set = self.allowed_fields is not None
+        is_field_kwarg_set = self.included_fields is not None
         is_exclude_kwarg_set = self.excluded_fields is not None
         msg = "May not set both `fields` and `exclude`"
         assert not(is_field_kwarg_set and is_exclude_kwarg_set), msg
@@ -153,11 +139,12 @@ class DynamicFieldsMixin(RequestQueryParserMixin):
             return instance.pk
         return super().to_representation(instance)
 
-    def get_allowed_fields(self):
-        fields = self._all_fields
-        if self.allowed_fields is not None:
+    @cached_property
+    def allowed_fields(self):
+        fields = super().fields
+        if self.included_fields is not None:
             # Drop all fields which are not specified on the `fields` kwarg.
-            allowed = set(self.allowed_fields)
+            allowed = set(self.included_fields)
             existing = set(fields)
             not_allowed = existing.symmetric_difference(allowed)
             for field_name in not_allowed:
@@ -184,7 +171,7 @@ class DynamicFieldsMixin(RequestQueryParserMixin):
             return True
         else:
             if raise_exception:
-                msg = "'%s' field is not found" % field_name
+                msg = "`%s` field is not found" % field_name
                 raise ValidationError(msg)
             return False
 
@@ -198,12 +185,39 @@ class DynamicFieldsMixin(RequestQueryParserMixin):
             return True
         else:
             if raise_exception:
-                msg = "'%s' is not a nested field" % field_name
+                msg = "`%s` is not a nested field" % field_name
                 raise ValidationError(msg)
             return False
 
+    @staticmethod
+    def is_valid_alias(alias, field):
+        if alias == field:
+            msg = (
+                "Invalid defenition of `%s` alias on `%s` field, "
+                "Alias can not be the same as the field name."
+            ) % (alias, field)
+            raise ValidationError(msg)
+
+        if len(alias) > restql_settings.MAX_ALIAS_LEN:
+            msg = (
+                "The length of `%s` alias has exceeded "
+                "the limit specified, which is %s characters."
+            ) % (alias, restql_settings.MAX_ALIAS_LEN)
+            raise ValidationError(msg)
+
     def include_fields(self):
-        all_fields = self.get_allowed_fields()
+        all_fields = self.allowed_fields
+
+        aliases = self.parsed_restql_query["aliases"]
+        for field, alias in aliases.items():
+            self.is_field_found(
+                field,
+                all_fields.keys(),
+                raise_exception=True
+            )
+            self.is_valid_alias(alias, field)
+            all_fields[alias] = all_fields[field]
+
         all_field_names = list(all_fields.keys())
 
         allowed_flat_fields = []
@@ -256,7 +270,7 @@ class DynamicFieldsMixin(RequestQueryParserMixin):
         return all_fields
 
     def exclude_fields(self):
-        all_fields = self.get_allowed_fields()
+        all_fields = self.allowed_fields
         all_field_names = list(all_fields.keys())
 
         # The format is  {nested_field: [sub_fields ...] ...}
@@ -304,7 +318,7 @@ class DynamicFieldsMixin(RequestQueryParserMixin):
         )
 
         if is_not_a_request_to_process:
-            return self.get_allowed_fields()
+            return self.allowed_fields
 
         is_top_retrieve_request = (
             self.field_name is None and
@@ -347,7 +361,7 @@ class DynamicFieldsMixin(RequestQueryParserMixin):
         if self.parsed_restql_query is None:
             # No filtering on nested fields
             # Retrieve all nested fields
-            return self.get_allowed_fields()
+            return self.allowed_fields
 
         # NOTE: self.parsed_restql_query["include"] not being empty
         # is not a guarantee that the exclude operator(-) has not been
@@ -367,16 +381,12 @@ class DynamicFieldsMixin(RequestQueryParserMixin):
             # return nothing
             return {}
 
-    @cached_property
-    def _all_fields(self):
-        return super().fields
-
     @property
     def fields(self):
         if self._use_restql_fields:
             # Use restql fields
             return self.restql_fields
-        return self._all_fields
+        return self.allowed_fields
 
 
 class EagerLoadingMixin(RequestQueryParserMixin):
@@ -399,7 +409,8 @@ class EagerLoadingMixin(RequestQueryParserMixin):
         query = {
             "include": ["*"],
             "exclude": [],
-            "arguments": {}
+            "arguments": {},
+            "aliases": {},
         }
         return query
 
@@ -407,11 +418,7 @@ class EagerLoadingMixin(RequestQueryParserMixin):
     def should_auto_apply_eager_loading(self):
         if hasattr(self, 'auto_apply_eager_loading'):
             return self.auto_apply_eager_loading
-        return getattr(
-            restql_settings,
-            "AUTO_APPLY_EAGER_LOADING",
-            True
-        )
+        return restql_settings.AUTO_APPLY_EAGER_LOADING
 
     def get_select_related_mapping(self):
         if hasattr(self, "select_related"):
@@ -720,7 +727,7 @@ class NestedUpdateMixin(BaseNestedMixin):
     """ Update Mixin """
     @staticmethod
     def constrain_error_prefix(field):
-        return "Error on %s field: " % (field,)
+        return "Error on `%s` field: " % (field,)
 
     @staticmethod
     def update_replaceable_foreignkey_related(instance, data):
@@ -811,6 +818,7 @@ class NestedUpdateMixin(BaseNestedMixin):
                 obj,
                 **kwargs,
                 data=values,
+                partial=True,  # Allow partial update since this is nested update
                 context=self.context
             )
             serializer.is_valid()
@@ -836,6 +844,7 @@ class NestedUpdateMixin(BaseNestedMixin):
                 obj,
                 **kwargs,
                 data=values,
+                partial=True,  # Allow partial update since this is nested update
                 context=self.context
             )
             serializer.is_valid()
@@ -882,7 +891,7 @@ class NestedUpdateMixin(BaseNestedMixin):
                     )
                 else:
                     message = (
-                        "%s is an invalid operation, " % (operation,)
+                        "`%s` is an invalid operation" % (operation,)
                     )
                     raise ValidationError(message)
         return instance
@@ -925,7 +934,7 @@ class NestedUpdateMixin(BaseNestedMixin):
                     )
                 else:
                     message = (
-                        "%s is an invalid operation, " % (operation,)
+                        "`%s` is an invalid operation" % (operation,)
                     )
                     raise ValidationError(message)
         return instance
